#
#	Common code for dealing with the codesign command line too
#

class Codesign
	
	def self._codesignToolLocation
		codesign_tool_path = `xcrun -find codesign`.strip
		return nil, "couldn't locate the codesign binary" if codesign_tool_path.nil?
		codesign_tool_path
	end
	
	def self._invokeCodesignWithEnvironmentAndArguments(environment = {}, arguments = [])
		codesign_location, codesign_location_error = _codesignToolLocation
		return false, codesign_location_error if codesign_location.nil?
		
		if environment.nil?
			environment = {}
		end
		
		task_succeeded = system(environment, codesign_location, *arguments)
		return false, "codesign returned an error" unless task_succeeded
		
		return true
	end
	
	def self.signBundleAtLocationUsingIdentityAndPreserveAllMetadata(bundle_location = nil, identity = nil)
		if bundle_location.nil?
			return false, "no location given"
		end
		
		if identity.nil?
			return false, "no identity given"
		end
		
		environment = {}
		codesign_allocate_tool_path = `xcrun -find codesign_allocate`.strip
		environment["CODESIGN_ALLOCATE"] = codesign_allocate_tool_path unless codesign_allocate_tool_path.length == 0
		
		arguments = []
		arguments.concat ["--sign", "#{identity}"]

		realMacSoftwareKeychainPath = File.expand_path("~/Library/Keychains/RealMacSoftware.keychain")
		if File.exist?(realMacSoftwareKeychainPath)
			arguments.concat ["--keychain", realMacSoftwareKeychainPath]
		end

		arguments << "--force"
		arguments << "--verbose=4"
		arguments << "--preserve-metadata=identifier,entitlements,requirements"
		arguments << "#{bundle_location}"
		
		return _invokeCodesignWithEnvironmentAndArguments environment, arguments
	end
	
	def self.validateBundleAtLocationWithRequirementReturningError(location = nil, requirement = nil)
		codesign_location, codesign_location_error = _codesignToolLocation
		return false, codesign_location_error if codesign_location.nil?
		
		arguments = []
		arguments << "--verify"
		arguments << "--verbose=4"
		unless requirement.nil?
			arguments << "-R=#{requirement}"
		end
		arguments << location
		
		return self._invokeCodesignWithEnvironmentAndArguments nil, arguments
	end
	
	def self.validateBundleAtLocationReturningError(location = nil)
		return validateBundleAtLocationWithRequirementReturningError(location, nil)
	end
end
