# xcarchive.rb
# 
# Common code for dealing with xcarchive bundles
#

class Xcarchive
	
	require 'osx/cocoa'
	include OSX
	
	def _errorWithDescription(description = "")
		userInfo = NSDictionary.dictionaryWithObject_forKey description, NSLocalizedDescriptionKey
		return NSError.errorWithDomain_code_userInfo "xcarchive", 0, userInfo
	end
	
	def readApplicationLocationInArchiveAtLocationWithError(archiveLocation = nil)
		return false, _errorWithDescription("no xcarchive path given") unless NSFileManager.defaultManager.fileExistsAtPath archiveLocation.path
		
		infoPlistPath = archiveLocation.path.stringByAppendingPathComponent "Info.plist"
		return false, _errorWithDescription("xcarchive doesn't contain an Info.plist") unless NSFileManager.defaultManager.fileExistsAtPath infoPlistPath
		
		infoPlist = NSDictionary.dictionaryWithContentsOfFile infoPlistPath
		return false, _errorWithDescription("xcarchive Info.plist is corrupt") unless infoPlist
		
		applicationPathSuffix = infoPlist.valueForKeyPath "ApplicationProperties.ApplicationPath"
		return false, _errorWithDescription("xcarchive doesn't contain an application path, it may contain zero products or more than one") unless applicationPathSuffix
		
		applicationLocation = archiveLocation.URLByAppendingPathComponent("Products").URLByAppendingPathComponent(applicationPathSuffix)
		return false, _errorWithDescription("xcarchive doesn't contain an application at the path specified, it may have been deleted") unless NSFileManager.defaultManager.fileExistsAtPath applicationLocation.path
		
		@archiveLocation = archiveLocation
		@applicationLocation = applicationLocation
		return @applicationLocation
	end
	
end
