#!/System/Library/Frameworks/Ruby.framework/Versions/1.8/usr/bin/ruby

require 'osx/cocoa'
include OSX

libraryDirectoryPath = File.dirname(__FILE__)
$LOAD_PATH << libraryDirectoryPath

require 'xcarchive.rb'

def usage
	print "Usage:\n"
	print "-archivePath: path to the xcarchive bundle to be verified [required]\n"
	print "-fixturesPath: path to the directory containing the plist fixtures [required]\n"
	print "\n"
	print "Example:\n"
	print "ruby xcarchive_check.rb\n -archivePath ~/Projects/Build\\ Archive/Courier/Courier_4770_1.2.1rc1-appstore.xcarchive -fixturesPath ~/Projects \n"
	print "\n"
	exit 1
end

if ARGV.count == 0
	usage
end

def start
	print "============ ARCHIVE VALIDATION STARTED ============\n"
	print "\n"
end

def fail(reason)
	print "\n"
	print "============ ARCHIVE VALIDATION FAILURE ============\n"
	print "\n"
	print "error: #{reason}\n"
	print "\n"
	exit 1
end

def finish
	print "\n"
	print "============ ARCHIVE VALIDATION SUCCESS ============\n"
end


# Check arguments

archivePath = NSUserDefaults.standardUserDefaults.stringForKey "archivePath"
if archivePath.nil?
	fail "an archivePath must be specified using -archivePath"
end
unless NSFileManager.defaultManager.fileExistsAtPath archivePath
	fail "archive doesn't exist at the specified path"
end

fixturesPath = NSUserDefaults.standardUserDefaults.stringForKey "fixturesPath"
if fixturesPath.nil?
	fail "a fixtures directory must be specified using -fixturesPath"
end
unless NSFileManager.defaultManager.fileExistsAtPath fixturesPath
	fail "fixtures directory does't exist at the specified path"
end

standardNamingScheme = archivePath.lastPathComponent.stringByDeletingPathExtension
standardNamingSchemeComponents = standardNamingScheme.componentsSeparatedByString "_"

applicationName = standardNamingSchemeComponents[0]

bundleVersion = standardNamingSchemeComponents[1]

marketingVersionPlusConfiguration = standardNamingSchemeComponents[2]
marketingVersionPlusConfigurationComponents = marketingVersionPlusConfiguration.componentsSeparatedByString "-"
configuration = marketingVersionPlusConfigurationComponents[1]

fixturePath = fixturesPath.stringByAppendingPathComponent "#{applicationName}-#{configuration}.plist"
if fixturePath.nil?
	fail "couldn't construct fixture path for application name #{applicationName} and configuration #{configuration}"
end
unless NSFileManager.defaultManager.fileExistsAtPath fixturePath
	fail "didn't find fixture at expected location #{fixturePath}"
end


#

start


# Check archive for validity

xcarchive = Xcarchive.new
applicationLocation, applicationLocationError = xcarchive.readApplicationLocationInArchiveAtLocationWithError NSURL.fileURLWithPath(archivePath)
fail "couldn't check xcarchive, #{applicationLocationError.localizedDescription}" if applicationLocation.nil?

print "Application found at '#{applicationLocation.path}'\n"


#

finish


# Check bundle

print "\n"

checkScriptFileName = "application_check.rb"
checkScriptFilePath = libraryDirectoryPath.to_ns.stringByAppendingPathComponent(checkScriptFileName)

checkScriptArguments = NSMutableArray.array
checkScriptArguments << "-applicationPath"
checkScriptArguments << applicationLocation.path
checkScriptArguments << "-fixturePath"
checkScriptArguments << fixturePath

$stdout.flush
validateTask = NSTask.launchedTaskWithLaunchPath_arguments_ checkScriptFilePath, checkScriptArguments
validateTask.waitUntilExit

exit validateTask.terminationStatus
